==> blackdynamite-1.0.1.tar.gz: blackdynamite-1.0.1/BlackDynamite/__init__.py <==
#!/usr/bin/env python3
# flake8: noqa
# This program is free software: you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published by
#     the Free Software Foundation, either version 3 of the License, or
#     (at your option) any later version.
#
#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.
#
#     You should have received a copy of the GNU General Public License
#     along with this program.  If not, see <https://www.gnu.org/licenses/>.

from . import bdparser
from . import job
# from . import run_sql
from . import run_zeo
from . import base
# from . import base_psql
from . import base_zeo
from . import runselector
from . import jobselector
# from . import conffile_sql
from . import conffile_zeo
from . import BDstat
from . import lowercase_btree
from . import loader
from . import coating

from .bdparser import *
# from .run_sql import *
from .run_zeo import *
from .job import *
from .base import *
# from .base_psql import *
from .base_zeo import *
from .runselector import *
from .jobselector import *
# from .conffile_sql import *
from .conffile_zeo import *
from .BDstat import *
from .lowercase_btree import *

__all__ = ["job", "base"]
__all__.extend(bdparser.__all__)
__all__.extend(base.__all__)
# __all__.extend(base_psql.__all__)
__all__.extend(base_zeo.__all__)
__all__.extend(runselector.__all__)
__all__.extend(jobselector.__all__)
# __all__.extend(conffile_sql.__all__)
__all__.extend(conffile_zeo.__all__)
__all__.extend(BDstat.__all__)

# try:
#    import graphhelper
#    __all__.append("graphhelper")
#    from graphhelper import *
#    __all__.extend(graphhelper.__all__)
# except:
#    print "graphhelper not loaded"

==> blackdynamite-1.2.0.tar.gz: blackdynamite-1.2.0/BlackDynamite/__init__.py <==
#!/usr/bin/env python3
# flake8: noqa
# This program is free software: you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published by
#     the Free Software Foundation, either version 3 of the License, or
#     (at your option) any later version.
#
#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.
#
#     You should have received a copy of the GNU General Public License
#     along with this program.  If not, see <https://www.gnu.org/licenses/>.

from . import (BDstat, base, base_zeo, bdparser, coating, conffile_zeo, job,
               jobselector, loader, lowercase_btree, run_zeo, runselector)
from .base import *
from .base_zeo import *
from .bdparser import *
from .BDstat import *
from .conffile_zeo import *
from .job import *
from .jobselector import *
from .lowercase_btree import *
from .run_zeo import *
from .runselector import *

__all__ = ["job", "base"]
__all__.extend(bdparser.__all__)
__all__.extend(base.__all__)
__all__.extend(base_zeo.__all__)
__all__.extend(runselector.__all__)
__all__.extend(jobselector.__all__)
__all__.extend(conffile_zeo.__all__)
__all__.extend(BDstat.__all__)


################################################################

from importlib.metadata import PackageNotFoundError, version

try:
    __version__ = version("blackdynamite")
except PackageNotFoundError:
    pass
